from hub_pip.api.model.NameValuePair import NameValuePair


class VersionBomPolicyStatusView(object):

    component_version_status_counts = None
    overall_status = None
    updated_at = None

    attribute_map = {
        'component_version_status_counts': 'componentVersionStatusCounts',
        'overall_status': 'overallStatus',
        'updated_at': 'updatedAt'
    }

    attribute_schema = {
        "component_version_status_counts": [NameValuePair]
    }

    def __init__(self):
        pass

    def get_in_violation(self):
        return self._get_value("IN_VIOLATION")

    def get_in_violation_but_overridden(self):
        return self._get_value("IN_VIOLATION_OVERRIDDEN")

    def get_not_in_violation(self):
        return self._get_value("NOT_IN_VIOLATION")

    def _get_value(self, value_name):
        for count_pair in self.component_version_status_counts:
            if count_pair.name == value_name:
                return str(count_pair.value)
        return "0"  # No components were found



import os

TREE_EXTENSION = "_tree.txt"
FLAT_EXTENSION = "_flat.txt"
BDIO_EXTENSION = ".jsonld"


def get_file_path(file_name, output_path, extension=None):
    file_path = output_path + "/"
    file_path += file_name
    if extension:
        file_path += extension
    return file_path


def generate_file(data, file_name, output_path, file_extension=None):
    if not os.path.exists(output_path):
        os.makedirs(output_path)
    output_file_path = get_file_path(file_name, output_path, file_extension)
    with open(output_file_path, "w+") as output_file:
        output_file.write(data)
    return output_file_path



import os

import pip
import six

from helper import *
from hub_pip.BlackDuckCore import BlackDuckCore
from hub_pip.FileHandler import get_file_path, TREE_EXTENSION


class TestTreeList:

    def test_tree(self):
        config = get_config(VALID)
        self._test_tree(config, 5)

    def test_tree_with_requirements(self):
        config = get_config(VALID)
        config.requirements_file_path = REQUIREMENTS

        if six.PY2:
            self._test_tree(config, 64)
        else:
            self._test_tree(config, 60)

    def _test_tree(self, config, length):
        config.tree_list = True
        tree_list_name = get_file_path(
            "hub-pip", config.output_path, TREE_EXTENSION)

        core = BlackDuckCore(config)
        core.run()

        assert(os.path.exists(tree_list_name))

        tree_list = get_file(tree_list_name).strip().split("\n")

        assert(len(tree_list) == length)

        cleanup(tree_list_name)



from hub_pip.api.model.CodeLocationView import CodeLocationView


class PagedCodeLocationView(object):

    total_count = None
    items = None

    attribute_map = {
        "total_count": "totalCount",
        "items": "items",
    }

    attribute_schema = {
        "items": [CodeLocationView]
    }

    def __init__(self):
        pass



import os

import pip
import six

from helper import *
from hub_pip.BlackDuckCore import BlackDuckCore
from hub_pip.FileHandler import get_file_path, FLAT_EXTENSION


class TestFlatList:

    def test_flat_render(self):
        config = get_config(VALID)
        items = [
            "configparser",
            "docopt",
            "requests",
            "six"
        ]
        self._test_flat(config, items)

    def test_flat_render_with_requirements(self):
        config = get_config(VALID)
        config.requirements_file_path = REQUIREMENTS
        py2_items = [
            "Babel",
            "Delorean",
            "SQLAlchemy",
            "appdirs",
            "backports-abc",
            "botocore",
            "certifi",
            "collectd-gnocchi-status",
            "configparser",
            "docopt",
            "docutils",
            "environment-manager",
            "envmgr-cli",
            "future",
            "humanize",
            "hyml",
            "jmespath",
            "jsonpickle",
            "mjetplex",
            "numpy",
            "packaging",
            "progressbar2",
            "psutil",
            "psycopg2",
            "pyhomematic",
            "pymesh",
            "pynamodb",
            "pyparsing",
            "python-dateutil",
            "python-utils",
            "pytz",
            "pyvdp",
            "repoze.lru",
            "requests",
            "semver",
            "setuptools",
            "simplejson",
            "singledispatch",
            "six",
            "tabulate",
            "tornado",
            "tzlocal",
            "ustudio-hmac-tornado",
            "vceffort",
        ]

        py3_items = [
            "Babel",
            "Delorean",
            "SQLAlchemy",
            "appdirs",
            "botocore",
            "collectd-gnocchi-status",
            "configparser",
            "docopt",
            "docutils",
            "environment-manager",
            "envmgr-cli",
            "future",
            "humanize",
            "hyml",
            "jmespath",
            "jsonpickle",
            "mjetplex",
            "numpy",
            "packaging",
            "progressbar2",
            "psutil",
            "psycopg2",
            "pyhomematic",
            "pymesh",
            "pynamodb",
            "pyparsing",
            "python-dateutil",
            "python-utils",
            "pytz",
            "pyvdp",
            "repoze.lru",
            "requests",
            "semver",
            "setuptools",
            "simplejson",
            "six",
            "tabulate",
            "tornado",
            "tzlocal",
            "ustudio-hmac-tornado",
            "vceffort",
        ]
        if six.PY2:
            self._test_flat(config, py2_items)
        else:
            self._test_flat(config, py3_items)

    def _test_flat(self, config, items):

        config.flat_list = True
        flat_list_name = get_file_path(
            "hub-pip", config.output_path, FLAT_EXTENSION)

        core = BlackDuckCore(config)
        core.run()

        assert(os.path.exists(flat_list_name))

        flat_list = pip.req.parse_requirements(
            flat_list_name, session=pip.download.PipSession())

        count = 0
        for item in flat_list:
            count += 1
            assert(item.req.name in items)

        "assert(count ",

        cleanup(flat_list_name)



import json
import time

from hub_pip.api.CodeLocationsDataService import CodeLocationsDataService
from hub_pip.api.ProjectDataService import ProjectDataService
from hub_pip.api.RestConnection import RestConnection
from hub_pip.api.ScanSummaryDataService import ScanSummaryDataService


class WaitingDataService(object):

    rest_connection = None
    config = None

    def __init__(self, rest_connection, config):
        self.rest_connection = rest_connection
        self.config = config

    def wait_for_project(self, project_name, project_version_name):
        rest_connection = self.rest_connection
        project_data_service = ProjectDataService(rest_connection)
        project_version_view = None
        hub_timeout = time.time() + self.config.hub_server_config.hub_timeout
        while project_version_view is None and time.time() < hub_timeout:
            project_version_view = project_data_service.get_project_version_view(
                project_name, project_version_name)
            if project_version_view is None:
                time.sleep(2)
        if project_version_view is None:
            raise Exception("The hub timed out on project creation")
        return project_version_view

    def wait_for_scan(self, project_version_view):
        rest_connection = self.rest_connection
        code_location_data_service = CodeLocationsDataService(rest_connection)
        hub_timeout = time.time() + self.config.hub_server_config.hub_scan_timeout

        print("Looking for pending scan")
        scans = []
        while scans == [] and time.time() < hub_timeout:
            scans = self.get_pending_scans(project_version_view)
            time.sleep(0.5)
        print("Found " + str(len(scans)) +
              " pending scan(s). Waiting for them to finish")

        while scans != [] and time.time() < hub_timeout:
            scans = self.get_pending_scans(project_version_view)
            time.sleep(0.5)
        print("Pending scans finished")

    def get_pending_scans(self, project_version_view):
        rest_connection = self.rest_connection
        code_location_data_service = CodeLocationsDataService(rest_connection)
        scan_summary_data_service = ScanSummaryDataService(rest_connection)
        scan_links = []

        paged_code_locations = code_location_data_service.get_paged_code_location_view(
            project_version_view)
        for code_location_view in paged_code_locations.items:
            if code_location_view.type == "BOM_IMPORT":
                paged_scan_summary_view = scan_summary_data_service.get_paged_scan_summary_view(
                    code_location_view)
                for scan_summary_view in paged_scan_summary_view.items:
                    if scan_summary_view.status != "COMPLETE":
                        scan_links.append(scan_summary_view.metadata.href)
        return scan_links



import json

from hub_pip.api.RestConnection import RestConnection
from hub_pip.api.model.PagedScanSummaryView import PagedScanSummaryView


class ScanSummaryDataService(object):

    rest_connection = None

    def __init__(self, rest_connection):
        self.rest_connection = rest_connection

    def get_paged_scan_summary_view(self, code_location_view):
        rest_connection = self.rest_connection
        scan_summary_link = None
        for link in code_location_view.metadata.links:
            if link["rel"] == "scans":
                scan_summary_link = link["href"]
                break
        if scan_summary_link is None:
            raise Exception("scans metadata not found in project version view")

        paged_scan_summary_view = rest_connection.get_view_from_link(
            PagedScanSummaryView, scan_summary_link)
        return paged_scan_summary_view




import distutils
import json
import os
import tempfile
import traceback

import pip
import pkg_resources
from setuptools.package_index import PackageIndex

from hub_pip.BlackDuckPackage import BlackDuckPackage
from hub_pip.FileHandler import *
from hub_pip.LogHandler import *
from hub_pip.TreeHandler import TreeHandler
from hub_pip.api.AuthenticationDataService import AuthenticationDataService, get_authenticated_api
from hub_pip.api.LinkedDataDataService import LinkedDataDataService
from hub_pip.api.ProjectDataService import ProjectDataService
from hub_pip.api.VersionBomPolicyDataService import VersionBomPolicyDataService
from hub_pip.api.WaitingDataService import WaitingDataService
from hub_pip.bdio.Bdio import Bdio


try:
    import configparser
except:
    from six.moves import configparser


class BlackDuckCore(object):

    config = None

    project_name = None
    project_version = None

    fail = False
    fail_on_match = False

    def __init__(self, black_duck_config):
        self.config = black_duck_config
        self.project_name = black_duck_config.project_name
        self.project_version = black_duck_config.project_version_name
        self.fail = not black_duck_config.ignore_failure

    def run(self):
        try:
            return self.execute()
        except Exception as e:
            error(message=e, exit=self.fail)
        return None

    def execute(self):
        info("Gathering dependencies")

        if self.project_name is None or self.project_version is None:
            error(error("Project name or version is not set", exit=self.fail))

        project_av = self.project_name + "==" + self.project_version
        pkgs = get_raw_dependencies(project_av, self.fail_on_match)
        if pkgs == []:
            error(project_av + " does not appear to be installed")

        pkg = pkgs.pop(0)  # The first dependency is itself
        pkg_dependencies = get_dependencies(pkg, self.fail_on_match)
        optional = self._fetch_optional_requirements()
        if optional:
            pkg_dependencies.extend(optional)

        info("Building dependency tree")

        tree = BlackDuckPackage(pkg.key, pkg.project_name,
                                pkg.version, pkg_dependencies)

        tree_handler = TreeHandler(tree)

        if self.config.flat_list:
            tree_handler.render_flat(self.config.output_path)
            info("Generated: Flat list")

        if self.config.tree_list:
            tree_list = tree_handler.render_tree(self.config.output_path)
            info("Generated: Tree list")

        if self.config.create_hub_bdio:
            self.create_bio(tree)

        if self.config.deploy_hub_bdio:
            self.deploy_bdio(tree)

        if self.config.check_policies:
            try:
                self.check_policies(tree)
            except:
                error(message="Failed to check component policies", exit=self.fail)

        return tree

    def create_bio(self, tree):
        bdio = Bdio(tree, self.config.code_location_name)
        bdio_data = bdio.generate_bdio()
        bdio.write_bdio(output_path=self.config.output_path)
        info("Generated: Black Duck I/O")

    def deploy_bdio(self, tree):
        info("Deploying: Black Duck I/O")
        bdio_file_path = self.config.output_path + "/" + tree.name + ".jsonld"
        try:
            assert os.path.exists(bdio_file_path)
            with open(bdio_file_path, "r") as bdio_file:
                bdio_data = bdio_file.read()
            rc = get_authenticated_api(self.config.hub_server_config)
            linked_data_data_service = LinkedDataDataService(rc)
            linked_data_response = linked_data_data_service.upload_bdio(
                bdio_data)
            info("Black Duck I/O successfully deployed to the hub")
        except:
            error(message="Failed to deploy Black Duck I/O to the hub", exit=self.fail)

    def check_policies(self, tree):
        info("Checking component policy status")
        rc = get_authenticated_api(self.config.hub_server_config)
        version_bom_policy_data_service = VersionBomPolicyDataService(rc)
        waiting_data_service = WaitingDataService(rc, self.config)

        info("Waiting for project to be created")
        project_version_view = waiting_data_service.wait_for_project(
            tree.name, tree.version)
        info("Project created")

        waiting_data_service.wait_for_scan(project_version_view)
        policy_status = version_bom_policy_data_service.get_version_bom_policy_view(
            project_version_view)

        string_builder = []
        string_builder.append("The Hub found: ")
        string_builder.append(policy_status.get_in_violation())
        string_builder.append(" components in violation, ")
        string_builder.append(
            policy_status.get_in_violation_but_overridden())
        string_builder.append(
            " components in violation, but overridden, and ")
        string_builder.append(policy_status.get_not_in_violation())
        string_builder.append(" components not in violation.")
        policy_log = "".join(string_builder)
        info(policy_log)

        if policy_status.overall_status == "IN_VIOLATION":
            error(message="The Hub found: " + policy_status.get_in_violation() +
                  " components in violation", exit=self.fail)
        return policy_status

    def _fetch_optional_requirements(self):
        requirements = self.config.requirements_file_path

        # If the user wants to include their requirements.txt file
        if requirements:
            try:
                assert os.path.exists(requirements), (
                    "The requirements file %s does not exist." % requirements)
                requirements = pip.req.parse_requirements(
                    requirements, session=pip.download.PipSession())
            except:
                error(message="Requirements file @ " + requirements +
                      " was not found", exit=self.fail)

        if requirements is None:
            return None

        pkg_dependencies = []
        for req in requirements:
            req_package = get_best(req.req, self.fail)
            if req_package:
                found = False
                for existing in pkg_dependencies:
                    if existing.key.lower() == req_package.key.lower():
                        found = True
                        break
                if not found:
                    req_dependencies = get_dependencies(
                        req_package, self.fail_on_match)
                    key = req_package.key
                    name = req_package.project_name
                    version = req_package.version
                    dependencies = req_dependencies
                    req_package = BlackDuckPackage(
                        key, name, version, dependencies)
                    pkg_dependencies.append(req_package)

        return pkg_dependencies


def get_raw_dependencies(package, fail_on_match):
    dependencies = []
    try:
        project_requirement = pkg_resources.Requirement.parse(package)

        environment = pkg_resources.Environment(
            distutils.sysconfig.get_python_lib(),
            platform=None,
            python=None
        )

        dependencies = pkg_resources.working_set.resolve(
            [project_requirement], env=environment)
    except Exception as e:
        m = "No matching packages found for declared dependency: "
        error(message=m + package, exit=fail_on_match)
    return dependencies


def get_dependencies(pkg, fail_on_match):
    dependencies = []

    for dependency in pkg.requires():
        pkg = get_best(dependency, fail_on_match)
        if pkg:
            pkg_dependencies = get_dependencies(pkg, fail_on_match)
            package = BlackDuckPackage(
                pkg.key, pkg.project_name, pkg.version, pkg_dependencies)
            dependencies.append(package)
    return dependencies


# Can take in an object with a key or just a string
def get_best(dependency, fail_on_match):
    installed = pip.get_installed_distributions(
        local_only=False, user_only=False)

    if hasattr(dependency, "key"):
        dependency = dependency.key
    elif hasattr(dependency, "name"):
        dependency = dependency.name

    for pkg in installed:
        if pkg.key.lower() == dependency.lower():
            return pkg
    m = "No matching packages found for declared dependency: "
    error(message=m + dependency, exit=fail_on_match)
    return None



import inspect
import json


def from_json_file(json_file, cls):
    json_ = json_file.read()
    return from_json_string(json_, cls)


def from_json_string(json_string, cls):
    json = json.loads(json_string)
    return map_to_object(json, cls)


def map_to_object(data, cls):  # data is a dictionary. cls is the class to convert to
    obj = cls()
    if data:
        for k, v in data.items():
            key = _exhange(obj, k)
            if key:
                setattr(obj, key, v)
        _exhange_properties(obj)
    return obj


def map_from_object(obj):
    dictionary = {}
    attr_map = obj.attribute_map
    for k, v in attr_map.items():
        attr = getattr(obj, k)
        if attr:
            dictionary[v] = attr
    return dictionary


def _exhange(obj, key):
    """Exchange provided key for mapped version"""
    if hasattr(obj, "attribute_map"):
        for k, v in obj.attribute_map.items():
            if v == key:
                return k
    return None


def _exhange_properties(obj):
    """Exchange provided key for schema class"""
    if hasattr(obj, "attribute_schema"):
        for k, v in obj.attribute_schema.items():
            data = None
            if isinstance(v, list) and v[0]:
                if inspect.isclass(v[0]):
                    data = [map_to_object(item, v[0])
                            for item in getattr(obj, k)]
                    setattr(obj, k, data)
            elif inspect.isclass(v):
                data = map_to_object(getattr(obj, k), v)
                setattr(obj, k, data)
            else:
                raise Exception(
                    "Value of attribute_schema is not a class or list of a single class")
    return None



from hub_pip.api.model.MetadataView import MetadataView


class ProjectView(object):

    description = None
    name = None
    project_level_adjustments = None
    project_tier = None
    source = None
    metadata = None

    attribute_map = {
        "description": "description",
        "name": "name",
        "project_level_adjustments": "projectLevelAdjustments",
        "project_tier": "projectTier",
        "source": "source",
        "metadata": "_meta"
    }

    attribute_schema = {
        "metadata": MetadataView
    }

    def __init__(self):
        pass



from hub_pip.LogHandler import *
from hub_pip.api.RestConnection import RestConnection

INVALID_MESSAGE = "The provided username and password are invalid for the hub @ "


class AuthenticationDataService(object):

    rest_connection = None

    def __init__(self, rest_connection):
        self.rest_connection = rest_connection

    def authenticate(self):
        # Sprinkle cookies into the session
        credentials = {
            "j_username": self.rest_connection.config.hub_username,
            "j_password": self.rest_connection.config.hub_password
        }
        response = self.rest_connection.make_post_request(
            self.rest_connection.JSPRING, credentials)
        return response


def get_authenticated_api(hub_server_config):
    rc = RestConnection(hub_server_config)
    authentication_data_service = AuthenticationDataService(rc)
    authentication_response = authentication_data_service.authenticate()
    try:
        authentication_response.raise_for_status()
    except:
        error(message=INVALID_MESSAGE + hub_server_config.hub_url)
        raise Exception(INVALID_MESSAGE + hub_server_config.hub_url)
    return rc



from io import StringIO

import six

from hub_pip.api.HubServerConfig import HubServerConfig


try:
    import configparser
except:
    from six.moves import configparser


class BlackDuckConfig(object):

    project_name = None
    project_version_name = None

    hub_server_config = None
    code_location_name = None

    output_path = "build/blackduck"
    requirements_file_path = None

    ignore_failure = True
    flat_list = False
    tree_list = False
    create_hub_bdio = True
    deploy_hub_bdio = False
    check_policies = False

    section_name = "Black Duck Config"

    def __init__(self):
        self.hub_server_config = HubServerConfig()

    @classmethod
    def from_nothing(self):
        return BlackDuckConfig()

    @classmethod
    def from_file(self, config_file_path):
        config_str = None
        with open(config_file_path, "r") as config_file:
            config_str = config_file.read()
        return self.from_string(config_str)

    @classmethod
    def from_string(self, config_str, black_duck_config=None):
        bd_config = black_duck_config
        if bd_config is None:
            bd_config = self.from_nothing()

        string_buffer = None
        if six.PY2:
            string_buffer = StringIO(unicode(config_str))
        else:
            string_buffer = StringIO(config_str)

        config = configparser.RawConfigParser()
        config.allow_no_value = True
        config.readfp(string_buffer)

        """Initialize defaults"""
        url = bd_config.hub_server_config.hub_url
        username = bd_config.hub_server_config.hub_username
        password = bd_config.hub_server_config.hub_password
        p_host = bd_config.hub_server_config.hub_proxy_host
        p_port = bd_config.hub_server_config.hub_proxy_port
        p_username = bd_config.hub_server_config.hub_proxy_username
        p_password = bd_config.hub_server_config.hub_proxy_password
        timeout = bd_config.hub_server_config.hub_timeout
        s_timeout = bd_config.hub_server_config.hub_scan_timeout

        code_loc = bd_config.code_location_name
        output_path = bd_config.output_path
        requirements = bd_config.requirements_file_path

        i_fail = bd_config.ignore_failure
        flat = bd_config.flat_list
        tree = bd_config.tree_list
        bdio = bd_config.create_hub_bdio
        deploy = bd_config.deploy_hub_bdio
        policies = bd_config.check_policies

        project = bd_config.project_name
        version = bd_config.project_version_name

        """Parse config string"""
        url = bd_config.get(config, url, "Hub-Url")

        username = bd_config.get(config, username, "Hub-Username")
        password = bd_config.get(config, password, "Hub-Password")
        p_host = bd_config.get(config, p_host, "Hub-Proxy-Host")
        p_port = bd_config.get(config, p_port, "Hub-Proxy-Port")
        p_username = bd_config.get(config, p_username, "Hub-Proxy-Username")
        p_password = bd_config.get(config, p_password, "Hub-Proxy-Password")
        timeout = bd_config.getfloat(config, timeout, "Hub-Timeout")
        s_timeout = bd_config.getfloat(config, s_timeout, "Hub-ScanTimeout")

        code_loc = bd_config.get(config, code_loc, "Hub-CodeLocationName")
        output_path = bd_config.get(config, output_path, "OutputDirectory")
        requirements = bd_config.get(config, requirements, "RequirementsFile")

        i_fail = bd_config.getboolean(config, i_fail, "IgnoreFailure")
        flat = bd_config.getboolean(config, flat, "CreateFlatDependencyList")
        tree = bd_config.getboolean(config, tree, "CreateTreeDependencyList")
        bdio = bd_config.getboolean(config, bdio, "CreateHubBdio")
        deploy = bd_config.getboolean(config, deploy, "DeployHubBdio")
        policies = bd_config.getboolean(config, policies, "CheckPolicies")

        project = bd_config.get(config, project, "Project-Name")
        version = bd_config.get(config, version, "Project-Version")

        bd_config.hub_server_config.hub_url = url
        bd_config.hub_server_config.hub_username = username
        bd_config.hub_server_config.hub_password = password
        bd_config.hub_server_config.hub_proxy_host = p_host
        bd_config.hub_server_config.hub_proxy_port = p_port
        bd_config.hub_server_config.hub_proxy_username = p_username
        bd_config.hub_server_config.hub_proxy_password = p_password
        bd_config.hub_server_config.hub_timeout = timeout
        bd_config.hub_server_config.hub_scan_timeout = s_timeout

        bd_config.code_location_name = code_loc
        bd_config.output_path = output_path
        bd_config.requirements_file_path = requirements

        bd_config.ignore_failure = i_fail
        bd_config.flat_list = flat
        bd_config.tree_list = tree
        bd_config.create_hub_bdio = bdio
        bd_config.deploy_hub_bdio = deploy
        bd_config.check_policies = policies

        bd_config.project_name = project
        bd_config.project_version_name = version

        verify(bd_config)
        verify(bd_config.hub_server_config)

        return bd_config

    def get(self, config, default, property_name):
        value = None
        try:
            value = config.get(self.section_name, property_name)
        except configparser.NoOptionError:
            value = default
        return value

    def getboolean(self, config, default, property_name):
        value = None
        try:
            value = config.getboolean(self.section_name, property_name)
        except configparser.NoOptionError:
            value = default
        return value

    def getfloat(self, config, default, property_name):
        value = None
        try:
            value = config.getfloat(self.section_name, property_name)
        except configparser.NoOptionError:
            value = default
        return value


def verify(obj):
    if obj:
        for k, v in obj.__dict__.items():
            if v == "None":
                obj.__dict__[k] = None





import os

from hub_pip import __version__
from hub_pip.BlackDuckConfig import BlackDuckConfig
from hub_pip.LogHandler import *


VALID = "valid.ini"
INVALID = "invalid.ini"
BROKEN = "broken.ini"

CLEANUP = True

BASE = "src/hub_pip/tests/resources/"

REQUIREMENTS = BASE + "requirements.txt"
SMALL_BDIO = BASE + "small_bdio.jsonld"
BIG_BDIO = BASE + "big_bdio.jsonld"


def get_config(file_name):
    file_path = BASE + file_name
    config = BlackDuckConfig.from_file(file_path)
    config.project_name = "hub-pip"
    config.project_version_name = __version__
    return config


def cleanup(files_to_remove):
    if CLEANUP:
        if isinstance(files_to_remove, list):
            for file in files_to_remove:
                cleanup(file)
        if os.path.exists(files_to_remove):
            os.remove(files_to_remove)
        else:
            debug(files_to_remove + " does not exist")
            assert(False)


def get_file(file_path):
    file_str = None
    with open(file_path, "r") as file:
        file_str = file.read()
    return file_str



import os

from setuptools import setup, find_packages

package_name = "hub-pip"
package_version = "0.0.7"

setup(
    name=package_name,
    version=package_version,
    author="Black Duck Software",
    author_email="bdsoss@blackducksoftware.com",
    description=(
        "Generates and deploys Black Duck I/O files for use with the Black Duck Hub"),
    license="Apache 2.0",
    keywords="hub-pip blackduck",
    url="https://github.com/blackducksoftware/hub-pip",
    install_requires=["configparser", "requests", "six", "docopt"],
    setup_requires=["pytest-runner"],
    tests_require=["pytest"],
    packages=find_packages("src"),
    package_dir={'': 'src'},
    include_package_data=True,
    package_data={
        '': ['*.md', '*.ini'],
    },
    entry_points={
        "console_scripts": [
            "hub_pip=hub_pip.Main:cli",
        ],
        "distutils.commands": [
            "hub_pip=hub_pip.BlackDuckPlugin:BlackDuckCommand",
        ]
    },
)



import sys
import traceback

DEBUG = True


def info(message):
    print(str(message))


def error(message=None, e_message=None, print_exception=DEBUG, exit=False):
    if message:
        print("ERROR >>>>>> " + str(message))
    if e_message and print_exception:
        print(e_message)
    if exit:
        print("hub-pip failed")
        sys.exit()


def debug(message=None, exit=False):
    if DEBUG:
        if message:
            print("DEBUG >>>>>> " + str(message))
        if exit:
            print("hub-pip failed")
            sys.exit()



class BdioProject(object):

    id = None
    type = "Project"
    name = None
    external_id = None
    relationships = None
    version = None

    attribute_map = {
        "id": "@id",
        "type": "@type",
        "name": "name",
        "external_id": "externalIdentifier",
        "relationships": "relationship",
        "version": "revision"
    }

    def __init__(self):
        pass

    def __eq__(self, other):
        if isinstance(other, BdioProject):
            id = self.id == other.id
            type = self.type == other.type
            name = self.name == other.name
            external_id = self.external_id == other.external_id
            version = self.version == other.version
            relationships = True
            if self.relationships is not None and other.relationships is not None:
                relationships = len(self.relationships) == len(
                    other.relationships)
                if relationships:
                    for relationship in self.relationships:
                        if not relationship in other.relationships:
                            relationships = False
                            break
            elif self.relationships != other.relationships:
                # One is set to None
                relationships = False
            return (id and type and name and external_id and version and relationships)
        else:
            return False

    def __ne__(self, other):
        return not self.__eq__(other)
